@@ -423,7 +423,7 @@ int main(int argc, const char **argv)
         if (setsockopt(dstSocket, SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(int)) != 0){
 		logfile = fopen (LOGFILE, "a");
 		now = time(NULL);
-		fprintf (logfile, "%24.24s SO_REUSEADDR(dstSocket) ERROR\n");
+		fprintf (logfile, "%24.24s SO_REUSEADDR(dstSocket) ERROR\n", ctime(&now));
 		fclose (logfile);
                 exit(-1);
         }
@@ -432,7 +432,7 @@ int main(int argc, const char **argv)
         if (setsockopt(udpSocket, SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(int)) != 0){
                 logfile = fopen (LOGFILE, "a");
                 now = time(NULL);
-                fprintf (logfile, "%24.24s SO_REUSEADDR(udpSocket) ERROR\n");
+                fprintf (logfile, "%24.24s SO_REUSEADDR(udpSocket) ERROR\n", ctime(&now));
                 fclose (logfile);
                 exit(-1);
         }
