@@ -232,3 +232,7 @@ unsigned	int	NodeProductID;
 
 FILE	*logfile;
 time_t	now;
+
+long int	rf_PacketCnt;
+long int	inet_PacketCnt;
+
