@@ -40,7 +40,6 @@ char	CurJitterBufferPnt;
 char	VoicePacketSW;
 extern	int	voice_pnt;
 
-
 void	from_rig(void)
 {
 	int	length;
@@ -62,7 +61,7 @@ void	from_rig(void)
 		}
 
         	usb_control_msg (udev, 0xC0, GET_HEADER, 0, 0, &rf_header.header2, 9, 100);
-  		usb_control_msg (udev, 0xC0, GET_AD_STATUS, 0, 0, &status, 1, 100);
+  		//usb_control_msg (udev, 0xC0, GET_AD_STATUS, 0, 0, &status, 1, 100);
 
 		ret_code = callcheck(rf_header.MyCall);
 		if (ret_code)
@@ -79,7 +78,7 @@ void	from_rig(void)
 		SendHeader = TRUE;
 		SendToInet = TRUE;
 		voice_pnt = 0;
-
+		rf_PacketCnt = 0;
 	} else {
 		/* rf voice read */
 		length = usb_control_msg (udev, 0xC0, GET_DATA, 0, 0, rig_buffer, 32, 100);
@@ -100,8 +99,12 @@ void	from_rig(void)
 				{
 					dv_frame.B_header.seq = Packet_Seq | 0x40;
 					send_voice_queue();
-					Packet_Seq++;
-					if (Packet_Seq > 20) Packet_Seq = 0;
+					//Packet_Seq++;
+					//if (Packet_Seq > 20) Packet_Seq = 0;
+					logfile = fopen (LOGFILE, "a");
+					now = time(NULL);
+					fprintf (logfile, "%24.24s Frome Rig %d packets\n", ctime(&now), rf_PacketCnt);
+					fclose (logfile);
 					headerRead = FALSE;
 					SendHeader = FALSE;
 					sprintf (msg,"CALLED FROM %8.8s", rf_header.MyCall);
@@ -141,6 +144,7 @@ void	from_rig(void)
 						}
 					}
 					send_voice_queue();
+					rf_PacketCnt++;
 					Packet_Seq++;
 					if (Packet_Seq > 20) Packet_Seq = 0;
 					voice_pnt = 0;
@@ -156,6 +160,10 @@ void	from_rig(void)
                                 COS_On = FALSE;
                                 header_gen = FALSE;
                                 SendHeader = FALSE;
+                                logfile = fopen (LOGFILE, "a");
+                                now = time(NULL);
+                                fprintf (logfile, "%24.24s Frome Rig %d packets\n", ctime(&now), rf_PacketCnt);
+                                fclose (logfile);
                                 return;
                         }
                 }
