@@ -7,13 +7,9 @@
 #include <stdio.h>
 #include <stdarg.h>
 #include <usb.h>
+#include "dsgwd_pi.h"
 #include "node.h"
 
-
-#define	VendorID	0x04d8
-#define ProductID	0x0300
-
-
 struct	usb_bus	*bus;
 struct	usb_bus	*busses;
 struct	usb_device	*dev;
@@ -33,12 +29,18 @@ void	init_usb(void)
 			if ((dev->descriptor.idVendor == VendorID)
 				&& (dev->descriptor.idProduct == ProductID))
 			{
-				printf ("Node Adapter found\n");
+				logfile = fopen (LOGFILE, "a");
+				now = time(NULL);
+				fprintf (logfile, "%24.24s Node Adapter found\n", ctime(&now));
+				fclose (logfile);
 				udev = usb_open(dev);
 				return;
 			}
 		}
 	}
-	printf ("Node Adapter not found\n");
+	logfile = fopen (LOGFILE, "a");
+	now = time(NULL);
+	fprintf (logfile, "%24.24s Node Adapter not found\n", ctime(&now));
+	fclose (logfile);
 	exit(-1);
 } 
